#region Copyright Syncfusion Inc. 2001 - 2013
// Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using Syncfusion.UI.Xaml.Charts;

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ColumnChart
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow 
    {
        public MainWindow()
        {
            InitializeComponent();
        }

      

        
        private void columnChart_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            SfChart chart = sender as SfChart;
            foreach (var item in chart.Behaviors)
            {
                if (item is CustomCrossHairbehavior)
                {
                    CustomCrossHairbehavior crosshair = item as CustomCrossHairbehavior;
                    foreach (UIElement item1 in crosshair.AdorningCanvas.Children)
                    {
                        if (!(item1 is ContentControl))
                            item1.Visibility = Visibility.Visible;
                        if (item1 is Line)
                        {
                            (item1 as Line).X1 = (item1 as Line).X2 = crosshair.X;
                            (item1 as Line).Y1 = crosshair.ChartArea.SeriesClipRect.Top;
                            (item1 as Line).Y2 = crosshair.ChartArea.SeriesClipRect.Height + crosshair.ChartArea.SeriesClipRect.Top;
                        }
                        if (item1 is Ellipse)
                        {
                            Canvas.SetLeft(item1, crosshair.X - 10);
                            Canvas.SetTop(item1, crosshair.ChartArea.SeriesClipRect.Height - crosshair.ChartArea.SeriesClipRect.Height / 2);
                        }
                    }
                }
            }
        }

        
     

    }
    public class CustomCrossHairbehavior : ChartCrossHairBehavior
    {
        public double X { get; set; }

        public Ellipse CursorElement = new Ellipse() { Width = 20, Height = 20, Fill = Brushes.Green,Visibility = Visibility.Collapsed };
       
        protected override void AttachElements()
        {
            CursorElement.MouseLeftButtonDown +=CursorElement_MouseLeftButtonDown; 
            CursorElement.MouseMove+=CursorElement_MouseMove; 
            base.AttachElements();
            if (!this.AdorningCanvas.Children.Contains(CursorElement) )
            {
                this.AdorningCanvas.Children.Add(CursorElement);
            }
          
        }


        void CursorElement_MouseMove(object sender, MouseEventArgs e)
        {
            if (e.LeftButton == MouseButtonState.Released)
                Flag = false;
        }
        
        void CursorElement_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            if(CursorElement.IsMouseOver)
            Flag = true;
        }

        protected override void OnSizeChanged(SizeChangedEventArgs e)
        {
            base.OnSizeChanged(e);
            var elements = this.AdorningCanvas.Children;
            double X =0;
            bool firstverticalline = false;
            foreach (UIElement item in elements)
            {
                item.Visibility = Visibility.Visible;
                if (item is UIElement)
                {
                    if (item is Line)
                    {
                        if (!firstverticalline)
                        X = (item as Line).X1 ;
                        firstverticalline = true;
                    }
                    if (item is Ellipse)
                    {
                        Canvas.SetLeft(item, X- 10);
                    }
                }
            }
        }
        protected override void OnMouseLeave(MouseEventArgs e)
        {
            base.OnMouseLeave(e);
            IsActivated = true;
        }
        
        public bool Flag = false;
        protected override void OnMouseMove(MouseEventArgs e)
        {
            var point = e.GetPosition(this.ChartArea);
            var elements = this.AdorningCanvas.Children;
            IsActivated = true;
            if (e.LeftButton == MouseButtonState.Pressed)
            {
                if (Flag)
                {
                    base.OnMouseMove(e);
                    IsActivated = true;
                    foreach (UIElement item in elements)
                    {
                        item.Visibility = Visibility.Visible;
                        if (item is UIElement)
                        {
                            if (item is Line)
                            {
                                (item as Line).X1 = (item as Line).X2 = point.X;
                                (item as Line).Y1 = this.ChartArea.SeriesClipRect.Top;
                                (item as Line).Y2 = this.ChartArea.SeriesClipRect.Height + this.ChartArea.SeriesClipRect.Top;
                            }
                            if (item is Ellipse)
                            {
                                Canvas.SetLeft(item, point.X-10);
                            }
                        }
                    }
                    
                }
                
            }
        }
    }



    public class CategoryDataViewModel
    {
        public CategoryDataViewModel()
        {
            CategoricalDatas = new ObservableCollection<CategoryData>();
            CategoricalDatas.Add(new CategoryData("Metal",1, 5));
            CategoricalDatas.Add(new CategoryData("Plastic",2, 10));
            CategoricalDatas.Add(new CategoryData("Silver",3, 15));
            CategoricalDatas.Add(new CategoryData("Iron",4, 20));

        }
        public ObservableCollection<CategoryData> CategoricalDatas
        {
            get;
            set;
        }
    }
    public class CategoryData : INotifyPropertyChanged
    {
        private string category; private double value;

        public CategoryData(string category,double id, double value)
        {
            Category = category; Value = value; CategoryId = id;
        }

        public string Category
        {
            get
            { return category; }
            set
            {
                if (category != value)
                {
                    category = value;
                    OnPropertyChanged("Category");
                }
            }
        }

        public double Value
        {
            get
            { return value; }
            set
            {
                if (this.value != value)
                {
                    this.value = value;
                    OnPropertyChanged("Value");
                }
            }
        }
        private double categoryId;
        public double CategoryId
        {
            get
            { return categoryId; }
            set
            {
                if (this.categoryId != value)
                {
                    this.categoryId = value;
                    OnPropertyChanged("CategoryId");
                }
            }
        }


        void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        public event PropertyChangedEventHandler PropertyChanged;
    } 
}
